@@ -42,7 +42,7 @@ typedef void (*TangleActionFunction)(TangleAction* action, GObject* source, cons
 
 void tangle_action_execute(TangleAction* action);
 void tangle_action_execute_full(TangleAction* action, GObject* source, const gchar* trigger, TangleProperties* properties);
-void tangle_action_execute_full_list(TangleAction* action, GObject* source, const gchar* trigger, const gchar* first_property_name, ...);
+void tangle_action_execute_full_list(TangleAction* action, GObject* source, const gchar* trigger, ...);
 void tangle_action_execute_full_valist(TangleAction* action, GObject* source, const gchar* trigger, va_list properties_list);
 void tangle_action_set_next_action(TangleAction* action, TangleAction* next_action);
 TangleAction* tangle_action_get_next_action(TangleAction* action);
