@@ -19,7 +19,16 @@
 
 G_DEFINE_TYPE(TangleBoxLayout, tangle_box_layout, TANGLE_TYPE_LAYOUT);
 
+enum {
+	PROP_0,
+	PROP_FOCUS_POSITION,
+	PROP_FOCUS_LENGTH
+};
+
 struct _TangleBoxLayoutPrivate {
+	gfloat focus_position;
+	gfloat focus_length;
+
 	gfloat interactive_width;
 	gfloat min_width;
 	gfloat natural_width;
@@ -44,6 +53,39 @@ struct _TangleBoxLayoutMetaPrivate {
 
 /* TangleBoxLayout */
 
+gfloat tangle_box_layout_get_focus_position(TangleBoxLayout* box_layout) {
+
+	return box_layout->priv->focus_position;
+}
+
+void tangle_box_layout_set_focus_position(TangleBoxLayout* box_layout, gfloat focus_position) {
+	TangleWidget* widget;
+	
+	if (box_layout->priv->focus_position != focus_position) {
+		box_layout->priv->focus_position = focus_position;
+		if ((widget = tangle_layout_get_widget(TANGLE_LAYOUT(box_layout)))) {
+			clutter_actor_queue_relayout(CLUTTER_ACTOR(widget));
+		}
+		g_object_notify(G_OBJECT(box_layout), "focus-position");
+	}
+}
+
+gfloat tangle_box_layout_get_focus_length(TangleBoxLayout* box_layout) {
+
+	return box_layout->priv->focus_length;
+}
+
+void tangle_box_layout_set_focus_length(TangleBoxLayout* box_layout, gfloat focus_length) {
+	TangleWidget* widget;
+	
+	if (box_layout->priv->focus_length != focus_length) {
+		box_layout->priv->focus_length = focus_length;
+		if ((widget = tangle_layout_get_widget(TANGLE_LAYOUT(box_layout)))) {
+			clutter_actor_queue_relayout(CLUTTER_ACTOR(widget));
+		}
+		g_object_notify(G_OBJECT(box_layout), "focus-length");
+	}
+}
 
 static void calculate_preferred_width(TangleBoxLayout* box_layout, TangleWidget* widget, gfloat for_height) {
 	GList* child_in_list;
@@ -214,7 +256,7 @@ static void tangle_box_layout_get_preferred_width(TangleLayout* layout, TangleWi
 		*min_width_p = box_layout->priv->min_width;
 	}
 	if (natural_width_p) {
-		*natural_width_p = box_layout->priv->natural_width;
+		*natural_width_p = box_layout->priv->natural_width + box_layout->priv->focus_length;
 	}
 }
 
@@ -230,18 +272,20 @@ static void tangle_box_layout_allocate(TangleLayout* layout, TangleWidget* widge
 	TangleBoxLayout* box_layout;
 	GList* child_in_list;
 	gfloat x;
+	gfloat real_x;
 	
 	box_layout = TANGLE_BOX_LAYOUT(layout);
 
 	calculate_preferred_width(box_layout, widget, height);
-	allocate_width(box_layout, widget, width);
+	allocate_width(box_layout, widget, width - box_layout->priv->focus_length);
 	
-	x = 0;
+	x = real_x = 0;
 	for (child_in_list = tangle_widget_get_children_readonly(widget); child_in_list; child_in_list = child_in_list->next) {
 		ClutterActor* actor;
 		TangleBoxLayoutMeta* box_layout_meta;
 		gfloat y;
 		gfloat actor_width;
+		gfloat real_actor_width;
 		gfloat actor_height;
 		ClutterActorBox actor_box;
 		
@@ -250,7 +294,7 @@ static void tangle_box_layout_allocate(TangleLayout* layout, TangleWidget* widge
 			box_layout_meta = TANGLE_BOX_LAYOUT_META(tangle_layout_get_meta(TANGLE_LAYOUT(box_layout), actor));
 
 			y = 0;
-			actor_width = box_layout_meta->priv->allocated_width;
+			actor_width = real_actor_width = box_layout_meta->priv->allocated_width;
 			tangle_layout_get_preferred_actor_height(layout, actor, actor_width, NULL, &actor_height);
 			if (actor_height > height) {
 				if (TANGLE_IS_ACTOR(actor) && tangle_actor_get_interacting(TANGLE_ACTOR(actor))) {
@@ -268,6 +312,10 @@ static void tangle_box_layout_allocate(TangleLayout* layout, TangleWidget* widge
 				actor_height = height;
 			}
 
+			if (x <= box_layout->priv->focus_position && x + actor_width > box_layout->priv->focus_position) {
+				actor_width += box_layout->priv->focus_length;
+			}
+
 			actor_box.x1 = x;
 			actor_box.x2 = x + actor_width;
 			actor_box.y1 = y;
@@ -275,6 +323,7 @@ static void tangle_box_layout_allocate(TangleLayout* layout, TangleWidget* widge
 			tangle_layout_allocate_actor(layout, actor, &actor_box, flags);
 
 			x += actor_width;
+			real_x += real_actor_width;
 		}
 	}
 	
@@ -287,6 +336,42 @@ static TangleLayoutMeta* tangle_box_layout_create_layout_meta(TangleLayout* layo
 	return tangle_box_layout_meta_new(layout, actor);
 }
 
+static void tangle_box_layout_set_property(GObject* object, guint prop_id, const GValue* value, GParamSpec* pspec) {
+	TangleBoxLayout* box_layout;
+	
+	box_layout = TANGLE_BOX_LAYOUT(object);
+
+	switch (prop_id) {
+		case PROP_FOCUS_POSITION:
+			tangle_box_layout_set_focus_position(box_layout, g_value_get_float(value));
+			break;
+		case PROP_FOCUS_LENGTH:
+			tangle_box_layout_set_focus_length(box_layout, g_value_get_float(value));
+			break;
+		default:
+			G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
+			break;
+	}
+}
+
+static void tangle_box_layout_get_property(GObject* object, guint prop_id, GValue* value, GParamSpec* pspec) {
+	TangleBoxLayout* box_layout;
+	
+	box_layout = TANGLE_BOX_LAYOUT(object);
+
+        switch (prop_id) {
+		case PROP_FOCUS_POSITION:
+			g_value_set_float(value, box_layout->priv->focus_position);
+			break;
+		case PROP_FOCUS_LENGTH:
+			g_value_set_float(value, box_layout->priv->focus_length);
+			break;
+	        default:
+		        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
+		        break;
+        }
+}
+
 static void tangle_box_layout_finalize(GObject* object) {
 	G_OBJECT_CLASS (tangle_box_layout_parent_class)->finalize(object);
 }
@@ -301,12 +386,37 @@ static void tangle_box_layout_class_init(TangleBoxLayoutClass* box_layout_class)
 
 	gobject_class->finalize = tangle_box_layout_finalize;
 	gobject_class->dispose = tangle_box_layout_dispose;
+	gobject_class->set_property = tangle_box_layout_set_property;
+	gobject_class->get_property = tangle_box_layout_get_property;
 
 	layout_class->get_preferred_width = tangle_box_layout_get_preferred_width;
 	layout_class->get_preferred_height = tangle_box_layout_get_preferred_height;
 	layout_class->allocate = tangle_box_layout_allocate;
 	layout_class->create_layout_meta = tangle_box_layout_create_layout_meta;
 
+	/**
+	 * TangleBoxLayout:focus-position:
+	 *
+	 * The position of the area of which length will be increased.
+	 */
+	g_object_class_install_property(gobject_class, PROP_FOCUS_POSITION,
+	                                g_param_spec_float("focus-position",
+	                                "Focus position",
+	                                "The position of the area of which length will be increased",
+	                                0.0, G_MAXFLOAT, 0.0,
+	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
+	/**
+	 * TangleBoxLayout:focus-length:
+	 *
+	 * The length of which used to increase the focused area.
+	 */
+	g_object_class_install_property(gobject_class, PROP_FOCUS_LENGTH,
+	                                g_param_spec_float("focus-length",
+	                                "Focus length",
+	                                "The length of which used to increase the focused area",
+	                                0.0, G_MAXFLOAT, 0.0,
+	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
+
 	g_type_class_add_private (gobject_class, sizeof (TangleBoxLayoutPrivate));
 }
 
