@@ -131,9 +131,6 @@ GObject* tangle_template_create_object_with_id(TangleTemplate* template, const g
 			}
 		}
 
-		/* TODO: This message will be removed soon! */
-		g_print("Created an object '%s' from the template '%s'.\n", id, clutter_get_script_id(G_OBJECT(template)));
-
 		if (!template->priv->script ||
 		    !CLUTTER_IS_SCRIPTABLE(object) ||
 		    !(scriptable = CLUTTER_SCRIPTABLE(object)) ||
@@ -458,8 +455,18 @@ static gboolean tangle_template_parse_custom_node(ClutterScriptable* scriptable,
 				/* Defer object resolution until the template is instantiated. */
 				param_spec = NULL;
 				check_subtemplate = TRUE;
+			} else if (G_PARAM_SPEC_VALUE_TYPE(param_spec) == TANGLE_TYPE_SPACING) {
+				TangleSpacing spacing;
+
+				if ((retvalue = tangle_spacing_parse_from_json(&spacing, node))) {
+					g_value_init(value, TANGLE_TYPE_SPACING);
+					g_value_set_boxed(value, &spacing);
+				}
+			}
+
+			if (!retvalue) {
+				retvalue = clutter_script_parse_node(script, value, name, node, param_spec);
 			}
-			retvalue = clutter_script_parse_node(script, value, name, node, param_spec);
 		}
 		g_type_class_unref(type_class);
 
